% This m-file includes the examples covered in the MATLAB tutorial session
% on October 6, 2016.
% Outline:
% 1) Environment
% 2) Basic Commands
% 3) Vectores and Matrices
% 4) M-files
% 5) For/While Loops, If-Else
% 6) Plotting
% 7) Transfer Funtions
% 
% Author: Mahdi Yousefi 
% Last update: October 6, 2016
% Reference: MATLAB help

%% Environment
% To use defined functions or saved variables, their path must be specified
% as the current directory or their path must be added to the current.
mkdir ../example;   % Making a new folder
addpath ../example; % Adding the defined path to the current directory
cd ../example;      % Changing the current directory

%% Basic Commands
% To define a variable, type of the variable doesn't need to be defined. For
% instance:
C = 'g';        % char
I = 123;        % int
F = 3.14;       % float
% basic math operators
a1 = 2;
a2 = 5.3;
a3 = 1.2e2;     % 120
a4 = 12e-3;     % 0.012
r1 = a1+a2;     % summation
r2 = a1-a2;     % subtraction
r3 = a1 * a2;   % multiplication
r4 = a1 / a2;   % division
r5 = a2 ^ a1;   % power  
% to define a complex variable either 'i' or 'j' can be used to specify the
% imaginary part:
c1 = 10+12j;
c2 = 12+10i;
r1 = abs(c1);   % absolute value
r2 = imag(c1);  % imagibary part
r3 = real(c1);  % real part
%% Vectores and Matrices
v1 = [2 3 4 5]; % 1 by 4 row vector 
v2 = [2; 3; 4]; % 3 by 1 column vector, semicolon (;) seperates columns
v3 = 0:.1:10;   % a vetor starting form 0 incrementing by .1 upto 10.
m1 = [1 2 3; 3 4 2]; % 2 by 3 matrix, semicolon (;) seperates columns, the matirx must be properly defined
m2 = zeros(3,4);     % 3 by 4 zero matrix
m3 = ones(2,3);      % 2 by 3 matrix with all elements equal to 1;
m4 = eye(2,2);       % 2 by 2 identity matrix
% using elements of arrays and matrices
dummy1 = v1(4);     % or dummy1 = v(1,4);
dummy2 = m1(2,3);    
% Changing elements of arrays and matrices
v2(3) = dummy1;     % or v2(3,1) = dummy1;
m2(2,1) = dummy2;
% Matrix operators
r1 = m1 + m3;       % summation
r2 = m1 - m3;       % subtraction
r3 = m4 * m1;       % multiplication
r4 = m4 ^ 2;        % power, r4 = m4 * m4 
r5 = inv(4);        % inverse
m5 = m1';           % Transpose
% Matrix elementwise operators
r6 = m1 .* 2;       % multiplying all elements of m1 by 2
r7 = m1 .* m3;      % elementwise multiplication of m1 and m3
r8 = m1 ./ 2;       % deviding all elements of m1 by 2
r9 = m1 .^3;        % elementwise power
% Other usefull commands
clc;        % clear Command Window
save('MyVar.mat');  % Save all Workspace variable into MyVar.mat
save('MyVar1.mat','r9') % Save only r9 into MyVar1.mat
load('MyVar.mat');      % Load MyVar.mat
delete('MyVar1.mat')    % Delete MyVar1.mat
clear r1   % clear a specific variable,
clear all  % clear all variables.
%% M-files
% Scripts can be saved as m-files.
InitVar
% Functions are saved as m-files. A function starts like this:
% function outputs=FncName(inputs)
[output1,output2] = MulDiv(2,3)
% startup.m executes commands of your choosing when the MATLAB program starts
% open startup.m
% startup
%% For/While Loops, If-Else
% for loop:
% for var=init:increment:final;
%     statement
% end
% Example:
for i = 1: 2: 10;
    dummy = i^2;
    disp(dummy);
end
% while loop:
% while condition
%     statement
% end
% Example:
m = 0;
while m <= 10;
    m = m + 1;
    disp(m);
end
% if-else:
% if condition1
%   statement1
% elseif condition2
%   statement2
% else
%   statement3
% end
% Example:
m = 1;
if m == 0
  disp('m is zero.');
elseif m < 0
  disp('m is negative.')
else
  disp('m is positive.')
end

%% Plotting
% Specifying signals we want to plot:
x = 0:.1:2*pi;
y1 = sin(x);
y2 = cos(x);
% 2d plot
figure(1)               % open a new fiqure
plot(x,y1,'Color','red', 'LineStyle' , ':','LineWidth', 4);
% modifying the plot as follows:
% changing axex font 
set(gca,'FontName','Times');
set(gca,'FontSize',14);   
% changing axex ticks
set(gca,'XTick',[0 pi/2 pi 3*pi/2 2*pi]);
set(gca,'XTickLabel',{'0', 'pi/2', 'pi', '3pi/2', '2pi'});
% Turn on grids
grid on;        % or ax.XGrid = 'on'; ax.YGrid = 'on';
% Specifying labels 
xlabel('x');            % or ax.XLabel.String = 'x'  
ylabel('y_1');          % or ax.YLabel.String = 'y_1' 
% Specifying axes limits
xlim([0 2*pi]);         % or ax.XLim = [0 2*pi]
ylim([-1.5 1.5]);     % or ax.YLim = [-1.5 1.5]
title ('sine wave');  % ax.Title.String = 'sine wave';
% Plotting variables in one plot
figure;               % open a new figure
h1 = plot(x,y1,'Color','blue', 'LineStyle' , '--','LineWidth', 4);
hold on
h2 = plot(x,y2,'Color','red', 'LineStyle' , ':','LineWidth', 4);
hold off
% or plot(x,y1,x,y2);
% specifying legened 
legend([h1,h2],{'sin','cos'}, 'FontName','Times','FontSize',16)
%% Transfer Funtions
% G= s/(s^2+3s+2)
num = [1 0];    % numerator of G
den = [1 3 2];  % denumerator of G
G = tf(num,den); % define G, tf(num,den)
G1 = zpk(G);    % Convert to zero-pole-gain representation
figure;         % open a new figure
pzmap(G);       % zero pole plot
figure;         % open a new figure
impulse(G)      % impulse response
figure;         % open a new figure
step(G);        % step response
figure;         % open a new figure
rlocus(G);         % root locus plot
% connecting transfer functions
H = tf([1 1],[1 2]);
F = feedback(G,H);  % feedback connection
S = series(G,H);    % or P = G*H, series connection
P = parallel(G,H);  % or P = G+H, parallel connection
Gd = c2d(G,1);      % discretize G, c2d(tf,sampleTime)
Gc = d2c(Gd);       % Convert a discrete model to a continuous model
% simulating a model
t = 0:1:20;        % time vector
u = 5*sin(t); % defining an inout
y = lsim(G,u,t);
figure;
subplot(2,1,1)
plot(t,y);      % plot input
ylabel('y');
xlabel('t');
subplot(2,1,2)
plot(t,u);      % plot output
ylabel('u');
xlabel('t');